==> streamtuner-0.11.1.tar.gz: streamtuner-0.11.1/src/sglib/sg-dumper.h <==
/*
 * $Id: sg-dumper.h,v 1.4 2004/01/05 19:44:09 jylefort Exp $
 *
 * Copyright (c) 2002, 2003 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _SG_DUMPER_H
#define _SG_DUMPER_H

#include <glib.h>
#include <stdarg.h>

typedef struct
{
  char		*filename;	/* the file to write */
  char		*tmpfile;	/* the temporary file (FILENAME.failed) we write into */

  GIOChannel	*io_channel;
  
  int		depth;		/* the current tab depth */
  gboolean	ok;		/* is everything ok so far? */
} SGDumper;

SGDumper	*sg_dumper_new	(const char	*filename,
				 GError		**err);
gboolean	sg_dumper_write	(SGDumper	*dumper,
				 GError		**err,
				 ...);
gboolean	sg_dumper_free	(SGDumper	*dumper,
				 GError		**err);

#endif /* _SG_DUMPER_H */

==> streamtuner_0.12.1.orig.tar.gz: streamtuner-0.12.1/src/sglib/sg-dumper.h <==
/*
 * $Id: sg-dumper.h,v 1.6 2004/03/08 05:35:40 jylefort Exp $
 *
 * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _SG_DUMPER_H
#define _SG_DUMPER_H

#include <glib.h>
#include <stdarg.h>

typedef struct
{
  char		*filename;	/* the file to write */
  char		*tmpfile;	/* the temporary file we write into */

  GIOChannel	*io_channel;
  
  int		depth;		/* the current tab depth */
  gboolean	ok;		/* is everything ok so far? */
} SGDumper;

SGDumper	*sg_dumper_new	(const char	*filename,
				 GError		**err);
gboolean	sg_dumper_write	(SGDumper	*dumper,
				 GError		**err,
				 ...);
gboolean	sg_dumper_free	(SGDumper	*dumper,
				 GError		**err);

#endif /* _SG_DUMPER_H */
